==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/Input/mpc/translations/mpc_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="59"/>
        <source>Musepack Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="61"/>
        <source>Musepack Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="121"/>
        <source>About Musepack Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="122"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/mpc/translations/mpc_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="62"/>
        <source>Musepack Plugin</source>
        <translation>Plugin Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="64"/>
        <source>Musepack Files</source>
        <translation>Arquivos Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="133"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Sobre o plugin Musepack Áudio</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="134"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Arquivo Qmmp Musepack Áudio</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="135"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>Taxa de bits</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Tamanho do arquivo</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
